@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, print_function, unicode_literals
+
 import django
+from aldryn_apphooks_config.managers.parler import (
+    AppHookConfigTranslatableManager, AppHookConfigTranslatableQueryset,
+)
 from django.contrib.sites.models import Site
-from django.db.models import Q
+from django.db import models
+from django.utils.timezone import now
 
 try:
     from collections import Counter
 except ImportError:
     from .compat import Counter
 
-from django.db import models
-from django.utils.timezone import now
-from parler.managers import TranslationManager, TranslatableQuerySet
-
 
 class TaggedFilterItem(object):
 
@@ -21,7 +23,7 @@ class TaggedFilterItem(object):
         o con gli stessi tag di un model o un queryset
         """
         tags = self._taglist(other_model, queryset)
-        return self.get_queryset().filter(taglist__in=tags)
+        return self.get_queryset().filter(tags__in=tags).distinct()
 
     def _taglist(self, other_model=None, queryset=None):
         """
@@ -29,17 +31,21 @@ class TaggedFilterItem(object):
         o queryset passati come argomento
         """
         from taggit.models import TaggedItem
-        filtro = None
+        filter = None
         if queryset is not None:
-            filtro = set()
+            filter = set()
             for item in queryset.all():
-                filtro.update(item.tags.all())
-            filtro = set([tag.id for tag in filtro])
+                filter.update(item.tags.all())
+            filter = set([tag.id for tag in filter])
         elif other_model is not None:
-            filtro = set(TaggedItem.objects.filter(content_type__model=other_model.__name__.lower()).values_list('tag_id', flat=True))
-        tags = set(TaggedItem.objects.filter(content_type__model=self.model.__name__.lower()).values_list('tag_id', flat=True))
-        if filtro is not None:
-            tags = tags.intersection(filtro)
+            filter = set(TaggedItem.objects.filter(
+                content_type__model=other_model.__name__.lower()
+            ).values_list('tag_id', flat=True))
+        tags = set(TaggedItem.objects.filter(
+            content_type__model=self.model.__name__.lower()
+        ).values_list('tag_id', flat=True))
+        if filter is not None:
+            tags = tags.intersection(filter)
         return list(tags)
 
     def tag_list(self, other_model=None, queryset=None):
@@ -72,13 +78,15 @@ class TaggedFilterItem(object):
         return sorted(tags, key=lambda x: -x.count)
 
 
-class GenericDateQuerySet(TranslatableQuerySet):
+class GenericDateQuerySet(AppHookConfigTranslatableQueryset):
     start_date_field = 'date_published'
+    fallback_date_field = 'date_modified'
     end_date_field = 'date_published_end'
     publish_field = 'publish'
 
     def on_site(self):
-        return self.filter(Q(sites__isnull=True) | Q(sites=Site.objects.get_current().pk))
+        return self.filter(models.Q(sites__isnull=True) |
+                           models.Q(sites=Site.objects.get_current().pk))
 
     def published(self):
         queryset = self.published_future()
@@ -92,8 +100,8 @@ class GenericDateQuerySet(TranslatableQuerySet):
         queryset = self.on_site()
         if self.end_date_field:
             qfilter = (
-                models.Q(**{'%s__gte' % self.end_date_field: now()})
-                | models.Q(**{'%s__isnull' % self.end_date_field: True})
+                models.Q(**{'%s__gte' % self.end_date_field: now()}) |
+                models.Q(**{'%s__isnull' % self.end_date_field: True})
             )
             queryset = queryset.filter(qfilter)
         return queryset.filter(**{self.publish_field: True})
@@ -102,8 +110,8 @@ class GenericDateQuerySet(TranslatableQuerySet):
         queryset = self.on_site()
         if self.end_date_field:
             qfilter = (
-                models.Q(**{'%s__lte' % self.end_date_field: now()})
-                | models.Q(**{'%s__isnull' % self.end_date_field: False})
+                models.Q(**{'%s__lte' % self.end_date_field: now()}) |
+                models.Q(**{'%s__isnull' % self.end_date_field: False})
             )
             queryset = queryset.filter(qfilter)
         return queryset.filter(**{self.publish_field: True})
@@ -115,7 +123,7 @@ class GenericDateQuerySet(TranslatableQuerySet):
         return self.active_translations(language_code=language).on_site()
 
 
-class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
+class GenericDateTaggedManager(TaggedFilterItem, AppHookConfigTranslatableManager):
     use_for_related_fields = True
 
     queryset_class = GenericDateQuerySet
@@ -145,13 +153,20 @@ class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
 
     def get_months(self, queryset=None):
         """
-        Get months with aggregate count (how much posts is in the month). Results are ordered by date.
+        Get months with aggregate count (how much posts is in the month).
+        Results are ordered by date.
         """
         if queryset is None:
             queryset = self.get_queryset()
         queryset = queryset.on_site()
-        dates = queryset.values_list(queryset.start_date_field, flat=True)
-        dates = [(x.year, x.month) for x in dates]
+        dates_qs = queryset.values_list(queryset.start_date_field, queryset.fallback_date_field)
+        dates = []
+        for blog_dates in dates_qs:
+            if blog_dates[0]:
+                current_date = blog_dates[0]
+            else:
+                current_date = blog_dates[1]
+            dates.append((current_date.year, current_date.month,))
         date_counter = Counter(dates)
         dates = set(dates)
         dates = sorted(dates, reverse=True)
